local mod = RW:Boss("Thorim", "Ulduar", "The Keepers of Ulduar")
local L

mod.BossIcon = [[Interface\Icons\achievement_dungeon_ulduarraid_ironsentinel_01]]

---------------------------
-- Variables
local tLightningChargeCast, tLightningChargeCD, wLightningChargem, mLightningChargeStack
local tHardmode, mPhase
local tUnbalancingStrikeDur, tUnbalancingStrikeCD, mUnbalancingStrike
local tBlizzardDur, tBlizzardCast, wBlizzard, wBlizzardRun

---------------------------
-- Init

function mod:OnRegister()
	L = mod:RegisterLocale(self:GetName(), "enUS", true)
	if L then
		L.YellPull = "Interlopers! You mortals who dare to interfere with my sport will pay.... Wait--you..."
		L.YellPhase2 = "Impertinent whelps, you dare challenge me atop my pedestal? I will crush you myself!"
		L.YellDeath = "Stay your arms! I yield!"
		L.Ding_msg = "Ding %d!"
		L.Ding_opt = "Power Up message"
		L.Powerbar = "Power Up"
		L.Powerbar_opt = "Power Up bar"

		L.Ding_sound_opt = "Power Up sound"
		L.HardMode = "Hard mode"
	end

	L = mod:GetLocale()
	self.L = L
	
	self:SetTrigger(L.YellPull, 32865)
	self:SetWin(L.YellDeath, 32865)

	tBerserk = self:BerserkTimer(369)

	tLightningChargeCast	= self:CastTimer(5, 62466)
	tLightningChargeCD		= self:CDTimer(11, 62466)
	tHardmode				= self:AchievementTimer(175, 2977, L.HardMode)
	tUnbalancingStrikeDur	= self:DurTargetTimer(15, 62130)
	tUnbalancingStrikeCD	= self:CDTimer(23, 62130)
	tBlizzardDur			= self:DurTimer(10, 62576)
	tBlizzardCast			= self:CastTimer(62576)
	
	wBlizzard				= self:CastWarning(62576)
	wBlizzardRun			= self:RunawayWarning(62576)
	wLightningCharge		= self:RunawayWarning(62466)
	
	mUnbalancingStrike		= self:TargetMessage(62130)
	mPhase					= self:PhaseMessage()
	
	self:AddBoolOption("Powerupsound", L.Ding_sound_opt, "Power Up", true, select(3, GetSpellInfo(24312)))
	self:AddBoolOption("Powerupbar", L.Powerbar_opt, "Power Up", true, select(3, GetSpellInfo(24312)))
	
	--self:AddGeneralOption(L.Ding_opt, "Power Up", select(3, GetSpellInfo(24312)))
	
	mLightningChargeStack	= self:CustomMessage(L.Ding_msg, L.Ding_opt, 24312, L.Ding_opt)
	
end

---------------------------
-- Locals
local castedCharge
local powerupStacks

local function updatePower()
	return powerupStacks, 20
end

---------------------------
-- Start

function mod:OnEngage(trigger)
	self:Track("LightningCharge", 62279, 62466)
	self:YellTrack("Phase2", L.YellPhase2)
	self:Track("UnbalancingStrike", 62130)
	self:Track("Blizzard", 62577, 62603, 62576, 62602)
	
	mod:SendMessage("RW_ShowRangeCheck", false, 10)
	castedCharge = false
	powerupStacks = 0
	tBerserk:Start()
	tHardmode:Start()
end

local function resetCharge() castedCharge = false end

function mod:LightningCharge(event, args)
	if event == "SPELL_CAST_SUCCESS" then
		if not castedCharge then
			tLightningChargeCast:Start()
			tLightningChargeCD:Schedule(5)
			wLightningCharge:Show()
			
			castedCharge = true
			self:Schedule("ResetCharge", 5, resetCharge)
		end
	end
	if event == "SPELL_AURA_APPLIED" or event == "SPELL_AURA_APPLIED_DOSE" then
		powerupStacks = args.amount or 1
		mLightningChargeStack:Show(args.amount)
		if self.DB.DingSound then
			PlaySoundFile("Sound\\Interface\\LevelUp.wav")
		end
	end
end

function mod:Phase2(event, msg, name)
	tBerserk:Cancel()
	tHardmode:Cancel()
	mPhase:Show(2)
	mod:SendMessage("RW_ShowRangeCheck", true, 10)
	self:SendMessage("RW_AddHealthFrame", updatePower, L.Powerbar, select(3, GetSpellInfo(24312)), "STACK")
end

function mod:UnbalancingStrike(event, args)
	if event == "SPELL_CAST_SUCCESS" then
		tUnbalancingStrikeCD:Start()
	end
	if event == "SPELL_AURA_APPLIED" then
		tUnbalancingStrikeDur:Start(args.dName)
		mUnbalancingStrike:Show(args.dName)
	end
end	

function mod:Blizzard(event, args)
	if event == "SPELL_CAST_SUCCESS" then
		tBlizzardCast:Start()
		wBlizzard:Show()
		tBlizzardDur:Start()
	end
	if event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wBlizzardRun:Show()
		end
	end
end	